@@ -21,6 +21,7 @@ if TYPE_CHECKING:
             "duration": float,
             "internal_url": str,
             "external_url": str,
+            "stream_url": str,  # optional
         },
         total=False,
     )
@@ -44,6 +45,8 @@ def determine_url_type(url: str) -> str:
         return "spotify"
     if url.startswith("https://soundcloud.com/"):
         return "soundcloud"
+    if url.startswith("https://www.jamendo.com/"):
+        return "jamendo"
     return "unknown"
 
 
