@@ -15,22 +15,14 @@ if TYPE_CHECKING:
 class UserManager:
     """This class counts active users and handles permissions."""
 
-    @classmethod
-    def has_controls(cls, user: AbstractUser) -> bool:
+    def has_controls(self, user: AbstractUser) -> bool:
         """Determines whether the given user is allowed to control playback."""
-        return (
-            user.username == "mod" or user.username == "pad" or user.username == "admin"
-        )
-
-    @classmethod
-    def has_pad(cls, user: AbstractUser) -> bool:
-        """Determines whether the given user is allowed to access the pad."""
-        return user.username == "pad" or user.username == "admin"
+        return user.username == "mod" or self.is_admin(user)
 
     @classmethod
     def is_admin(cls, user: AbstractUser) -> bool:
         """Determines whether the given user is the admin."""
-        return user.username == "admin"
+        return user.is_superuser
 
     # This dictionary needs to be static so the middleware can access it.
     last_requests: Dict[str, datetime] = {}
@@ -61,7 +53,9 @@ class UserManager:
     def partymode_enabled(self) -> bool:
         """Determines whether partymode is enabled,
         based on the number of currently active users."""
-        return len(UserManager.last_requests) >= self.base.settings.people_to_party
+        return (
+            len(UserManager.last_requests) >= self.base.settings.basic.people_to_party
+        )
 
 
 class SimpleMiddleware:
